@@ -1,10 +1,12 @@
 # -*- coding: utf-8 -*-
+from typing import Any
+
 from poetry.core.toml import TOMLFile
 
 
 class TomlFile(TOMLFile):
     @classmethod
-    def __new__(cls, *args, **kwargs):
+    def __new__(cls, *args, **kwargs):  # type: (*Any, **Any) -> TOMLFile
         import warnings
 
         warnings.warn(
